@@ -1,7 +1,11 @@
 """Defines JADE base model"""
 
+from pathlib import Path
+
 from pydantic import BaseModel
 
+from jade.utils.utils import load_data
+
 
 class JadeBaseModel(BaseModel):
     """Base class for JADE models."""
@@ -13,3 +17,8 @@ class JadeBaseModel(BaseModel):
         validate_all = True
         extra = "forbid"
         use_enum_values = False
+
+    @classmethod
+    def load(cls, path: Path):
+        """Load a model from a file."""
+        return cls(**load_data(path))
